@@ -35,6 +35,7 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-stock-dialogs.h>
+#include <gtk/gtkmessagedialog.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkstock.h>
 #include <libgnome/gnome-i18n.h>
@@ -90,27 +91,21 @@ nautilus_desktop_link_monitor_delete_link (NautilusDesktopLinkMonitor *monitor,
 					   NautilusDesktopLink *link,
 					   GtkWidget *parent_view)
 {
-	/* FIXME: Is this right? How to get them back?
-	 * Do we disallow this, or add a prefs ui to get them back? */
-	
 	switch (nautilus_desktop_link_get_link_type (link)) {
 	case NAUTILUS_DESKTOP_LINK_HOME:
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_DESKTOP_HOME_VISIBLE, FALSE);
-		break;
 	case NAUTILUS_DESKTOP_LINK_COMPUTER:
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_VISIBLE, FALSE);
-		break;
 	case NAUTILUS_DESKTOP_LINK_TRASH:
-		eel_preferences_set_boolean (NAUTILUS_PREFERENCES_DESKTOP_TRASH_VISIBLE, FALSE);
+		/* just ignore. We don't allow you to delete these */
 		break;
 	default:
 		eel_run_simple_dialog
 			(parent_view, 
 			 FALSE,
-			 _("You cannot delete a volume icon. If you want to eject "
-			   "the volume, please use Eject in the right-click menu of "
-			   "the volume."), 
-			 _("Can't delete volume"),
+			 GTK_MESSAGE_ERROR,
+			 _("You cannot delete a volume icon."),
+			 _("If you want to eject the volume, please use Eject in the "
+			   "right-click menu of the volume."),
+			 _("Can't Delete Volume"),
 			 GTK_STOCK_OK, NULL);
 		break;
 	}
@@ -121,13 +116,18 @@ create_volume_link (NautilusDesktopLinkMonitor *monitor,
 		    GnomeVFSVolume *volume)
 {
 	NautilusDesktopLink *link;
-	
+
+	link = NULL;
+
 	if (!gnome_vfs_volume_is_user_visible (volume)) {
 		return;
 	}
 
-	link = nautilus_desktop_link_new_from_volume (volume);
-	monitor->details->volume_links = g_list_prepend (monitor->details->volume_links, link);
+	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE)) {
+		link = nautilus_desktop_link_new_from_volume (volume);
+		monitor->details->volume_links = g_list_prepend (monitor->details->volume_links, link);
+	}
+	
 }
 
 
@@ -225,6 +225,30 @@ desktop_trash_visible_changed (gpointer callback_data)
 	}
 }
 
+static void
+desktop_volumes_visible_changed (gpointer callback_data)
+{
+	GnomeVFSVolumeMonitor *volume_monitor;
+	NautilusDesktopLinkMonitor *monitor;
+	GList *l, *volumes;
+	
+	volume_monitor = gnome_vfs_get_volume_monitor ();
+	monitor = NAUTILUS_DESKTOP_LINK_MONITOR (callback_data);
+
+	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE) && monitor->details->volume_links == NULL) {
+		volumes = gnome_vfs_volume_monitor_get_mounted_volumes (volume_monitor);
+		for (l = volumes; l != NULL; l = l->next) {
+			create_volume_link (monitor, l->data);
+			gnome_vfs_volume_unref (l->data);
+		}
+		g_list_free (volumes);
+	} else {
+		g_list_foreach (monitor->details->volume_links, (GFunc)g_object_unref, NULL);
+		g_list_free (monitor->details->volume_links);
+		monitor->details->volume_links = NULL;
+	}
+}
+
 static void
 nautilus_desktop_link_monitor_init (gpointer object, gpointer klass)
 {
@@ -253,6 +277,7 @@ nautilus_desktop_link_monitor_init (gpointer object, gpointer klass)
 	}
 
 	volume_monitor = gnome_vfs_get_volume_monitor ();
+	
 	volumes = gnome_vfs_volume_monitor_get_mounted_volumes (volume_monitor);
 	for (l = volumes; l != NULL; l = l->next) {
 		volume = l->data;
@@ -270,8 +295,10 @@ nautilus_desktop_link_monitor_init (gpointer object, gpointer klass)
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_TRASH_VISIBLE,
 				      desktop_trash_visible_changed,
 				      monitor);
+	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE,
+				      desktop_volumes_visible_changed,
+				      monitor);
 
-	
 	monitor->details->mount_id = g_signal_connect_object (volume_monitor, "volume_mounted",
 							      G_CALLBACK (volume_mounted_callback), monitor, 0);
 	monitor->details->unmount_id = g_signal_connect_object (volume_monitor, "volume_unmounted",
@@ -317,6 +344,9 @@ desktop_link_monitor_finalize (GObject *object)
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DESKTOP_TRASH_VISIBLE,
 					 desktop_trash_visible_changed,
 					 monitor);
+	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DESKTOP_VOLUMES_VISIBLE,
+					 desktop_volumes_visible_changed,
+					 monitor);
 
 	if (monitor->details->mount_id != 0) {
 		g_source_remove (monitor->details->mount_id);
