@@ -26,10 +26,9 @@
 #ifndef FM_PROPERTIES_WINDOW_H
 #define FM_PROPERTIES_WINDOW_H
 
-#include "fm-directory-view.h"
-
 #include <gtk/gtkwindow.h>
 #include <libnautilus-private/nautilus-file.h>
+#include <libnautilus/nautilus-view.h>
 
 typedef struct FMPropertiesWindow FMPropertiesWindow;
 
@@ -60,6 +59,6 @@ typedef struct FMPropertiesWindowClass FMPropertiesWindowClass;
 GType   fm_properties_window_get_type   (void);
 
 void 	fm_properties_window_present 	(GList *files,
-					 FMDirectoryView *directory_view);
+					 GtkWidget *parent_widget);
 
 #endif /* FM_PROPERTIES_WINDOW_H */
