@@ -69,6 +69,7 @@ typedef struct {
         void   (* set_title) (NautilusWindow *window, const char *title);
 
         void   (* merge_menus)   (NautilusWindow *window);
+        void   (* merge_menus_2)   (NautilusWindow *window);
         void   (* load_view_as_menu) (NautilusWindow *window);
         void   (* set_content_view_widget) (NautilusWindow *window, 
                                             NautilusViewFrame *frame);
@@ -109,9 +110,6 @@ struct NautilusWindow {
 
         /* All views */
         GList *views;
-
-        /* Window showed state (for saved_window_positions) */
-        NautilusWindowShowState show_state;
 };
 
 GType            nautilus_window_get_type             (void);
